@@ -20,12 +20,17 @@ class DHCPMetricsDataSource:
     ''' DHCP Metrics data provider
     '''             
     @staticmethod
-    def metric_records(router_entry, *, metric_labels = None, add_router_id = True):
-        if metric_labels is None:
-            metric_labels = []                
+    def metric_records(router_entry, *, metric_labels = None, add_router_id = True, dhcp_cache = True, translate = True, bound = False):
+        if metric_labels is None or dhcp_cache:
+            metric_labels = ['host_name', 'comment', 'active_address', 'address', 'mac_address', 'server', 'expires_after']  
+
+        if dhcp_cache and router_entry.dhcp_records:
+            return router_entry.dhcp_records
         try:
-            #dhcp_lease_records = router_entry.api_connection.router_api().get_resource('/ip/dhcp-server/lease').get(status='bound')
-            dhcp_lease_records = router_entry.api_connection.router_api().get_resource('/ip/dhcp-server/lease').call('print', {'active':''})
+            if bound:
+                dhcp_lease_records = router_entry.dhcp_entry.api_connection.router_api().get_resource('/ip/dhcp-server/lease').get(status='bound')
+            else:
+                dhcp_lease_records = router_entry.dhcp_entry.api_connection.router_api().get_resource('/ip/dhcp-server/lease').call('print', {'active':''})
 
             # translation rules
             translation_table = {}
@@ -33,12 +38,16 @@ class DHCPMetricsDataSource:
                 translation_table['comment'] = lambda c: c if c else ''           
             if 'host_name' in metric_labels:
                 translation_table['host_name'] = lambda c: c if c else ''           
-            if 'expires_after' in metric_labels:
+            if 'expires_after' in metric_labels and translate:
                 translation_table['expires_after'] = lambda c: parse_mkt_uptime(c) if c else 0       
             if 'active_address' in metric_labels:
                 translation_table['active_address'] = lambda c: c if c else ''        
 
-            return BaseDSProcessor.trimmed_records(router_entry, router_records = dhcp_lease_records, metric_labels = metric_labels, add_router_id = add_router_id, translation_table = translation_table)
+            records = BaseDSProcessor.trimmed_records(router_entry, router_records = dhcp_lease_records, metric_labels = metric_labels, add_router_id = add_router_id, translation_table = translation_table)
+            if dhcp_cache:
+                router_entry.dhcp_records = records
+            return records
+            
         except Exception as exc:
             print(f'Error getting dhcp info from router{router_entry.router_name}@{router_entry.config_entry.hostname}: {exc}')
             return None
